# Generated by Django 3.2.20 on 2023-07-15 22:04

import dj_veryfi.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Document',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content_type', models.CharField(max_length=150)),
                ('ocr', dj_veryfi.fields.OCRInvoiceOrReceiptField(blank=True, null=True)),
            ],
        ),
    ]
